@@ -135,6 +135,7 @@ static gint     spi_atk_bridge_key_listener            (AtkKeyEventStruct     *e
 							gpointer               data);
 static void     spi_atk_tidy_windows                   (void);
 static void     deregister_application                 (BonoboObject          *app);
+static void     reinit_register_vars                   (void);
 
 /* For automatic libgnome init */
 extern void gnome_accessibility_module_init     (void);
@@ -314,6 +315,7 @@ spi_atk_bridge_toplevel_removed (AtkObject *object,
   if (toplevels == 0)
     {
       deregister_application (app);
+      reinit_register_vars ();
     }
   if (toplevels < 0)
     {
@@ -572,6 +574,7 @@ spi_atk_register_event_listeners (void)
   add_signal_listener ("Gtk:AtkText:text-selection-changed");
   add_signal_listener ("Gtk:AtkText:text-changed");
   add_signal_listener ("Gtk:AtkText:text-caret-moved");
+  add_signal_listener ("Gtk:AtkText:text-attributes-changed");
   add_signal_listener ("Gtk:AtkTable:row-inserted");
   add_signal_listener ("Gtk:AtkTable:row-reordered");
   add_signal_listener ("Gtk:AtkTable:row-deleted");
@@ -1348,6 +1351,14 @@ spi_atk_tidy_windows (void)
     }
 }
 
+static void
+reinit_register_vars (void)
+{
+  registry = CORBA_OBJECT_NIL;
+  device_event_controller = CORBA_OBJECT_NIL;
+  this_app = NULL;
+}
+
 static void
 spi_atk_bridge_init_base (CORBA_any *any, AtkObject *obj, 
 			  Accessibility_Application *app, Accessibility_Role *role,
